/*
 * analogue_clock.cc
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "analogue_clock.h"
#include "config.h"
#include "Arduino.h"
#include "time.h"
#include "common.h"


// the segment that the hour hand should be at
static int _hour_segment;

// the segment that the minute hand should be at
static int _minute_segment;

// the segment that the second hand should be at
static int _second_segment;

// the flavour
int _flavour = 0;


void analogue_clock_press()
{
	if( ++_flavour >= 2 )
		_flavour = 0;
}


void analogue_clock_draw( int segment )
{
	bool draw_tick = segment && ( segment % ( NUM_SECOND_SEGMENTS * 5 ) == 0 ||
		segment == 1 || segment == NUM_SEGMENTS - 1 );
	bool draw_hour = segment == _hour_segment;
	bool draw_hour_side = 2 >=
		( abs( _hour_segment - segment ) + NUM_SEGMENTS ) % NUM_SEGMENTS;
	bool draw_minute = segment == _minute_segment;
	bool draw_minute_side = 1 >=
		( abs( _minute_segment - segment ) + NUM_SEGMENTS ) % NUM_SEGMENTS;

	bool draw_second = segment == _second_segment;

	// set the LEDs
	led( 9, _flavour == 0 );
	led( 8, draw_tick || draw_second );
	led( 7, draw_minute || draw_second );
	led( 6, draw_minute || draw_minute_side || draw_second );
	led( 5, draw_minute || draw_minute_side ||
				  draw_second || draw_hour );
	for( int a = 0; a <= 4; a++ )
		led( a, draw_minute || draw_minute_side ||
					  draw_second || draw_hour || draw_hour_side );
}


void analogue_clock_draw_reset()
{
	// calculate hand locations
	_hour_segment = ( Time::get_hours() % 12 ) * 5 * NUM_SECOND_SEGMENTS +
		( 5 * NUM_SECOND_SEGMENTS * Time::get_minutes() / 60 );
	_minute_segment = Time::get_minutes() * NUM_SECOND_SEGMENTS +
		( NUM_SECOND_SEGMENTS * Time::get_seconds() / 60 );
	_second_segment = Time::get_seconds() * NUM_SECOND_SEGMENTS;
}


void analogue_clock_activate()
{
	_flavour = 0;
}
