/*
 * nvram.h
 *
 * Copyright (C) 2012 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _NVRAM_H_
#define _NVRAM_H_


#include <EEPROM.h>


namespace Nvram
{
	enum {
		NVRAM_FONT = 0, // 1 byte
	};

	/**
	 * load something
	 *
	 * @param offset address to load from, use NVRAM_* enum
	 * @param data where to load to
	 */
	template< class T >
	void load( int offset, T &data )
	{
		unsigned char *p = reinterpret_cast< unsigned char * >( &data );
		for( unsigned int a = 0; a < sizeof( T ); a++ )
			*( p++ ) = EEPROM.read( offset++ );
	}

	/**
	 * Save something.
	 *
	 * @param offset address to save to, use NVRAM_* enum
	 * @param data to save
	 */
	template< class T >
	void save( int offset, T &data )
	{
		unsigned char *p = reinterpret_cast< unsigned char * >( &data );
		for( unsigned int a = 0; a < sizeof( T ); a++ )
			EEPROM.write( offset++, *( p++ ) );
	}

}


#endif //_NVRAM_H_
