/*
 * time.h
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _TIME_H_
#define _TIME_H_


namespace Time
{
	/**
	 * Get year.
	 *
	 * @return year
	 */
	int get_year();

	/**
	 * Get month.
	 *
	 * @return month, 1 to 12
	 */
	int get_month();

	/**
	 * Get month name.
	 *
	 * @return month name
	 */
	const char *get_month_name();

	/**
	 * Get day.
	 *
	 * @return date, 1 to 31
	 */
	int get_day();

	/**
	 * Get number suffix.
	 *
	 * @param number
	 * @return suffix
	 */
	const char *get_day_suffix();

	/**
	 * Get hours.
	 *
	 * @return hours, 0 to 23
	 */
	int get_hours();

	/**
	 * Get minutes.
	 *
	 * @return minutes, 0 to 59
	 */
	int get_minutes();

	/**
	 * Get seconds.
	 *
	 * @return seconds, 0 to 59
	 */
	int get_seconds();

	/**
	 * Update the time.
	 */
	void update();

	/**
	 * Initialise time data
	 */
	void init();

	/**
	 * Increment the hours and save the time.
	 */
	void inc_hours();

	/**
	 * Increment the minutes and save the time.
	 */
	void inc_minutes();

	/**
	 * Reset the seconds and save the time.
	 */
	void reset_seconds();

	/**
	 * Increment the year and save the time.
	 */
	void inc_year();

	/**
	 * Increment the month and save the time.
	 */
	void inc_month();

	/**
	 * Increment the day and save the time.
	 */
	void inc_day();

};


#endif //_TIME_H_
